@@ -6,8 +6,7 @@ use skia_bindings::{
 use std::{fmt, iter, marker::PhantomData, mem, ptr};
 
 pub type Region = Handle<SkRegion>;
-unsafe impl Send for Region {}
-unsafe impl Sync for Region {}
+unsafe_send_sync!(Region);
 
 impl NativeDrop for SkRegion {
     fn drop(&mut self) {
@@ -39,10 +38,7 @@ impl fmt::Debug for Region {
 }
 
 pub use skia_bindings::SkRegion_Op as RegionOp;
-#[test]
-fn test_region_op_naming() {
-    let _ = RegionOp::ReverseDifference;
-}
+variant_name!(RegionOp::ReverseDifference, region_op_naming);
 
 impl Region {
     pub fn new() -> Region {
@@ -332,11 +328,7 @@ impl QuickReject<Region> for Region {
 #[repr(transparent)]
 pub struct Iterator<'a>(SkRegion_Iterator, PhantomData<&'a Region>);
 
-impl NativeTransmutable<SkRegion_Iterator> for Iterator<'_> {}
-#[test]
-fn test_iterator_layout() {
-    Iterator::test_layout();
-}
+native_transmutable!(SkRegion_Iterator, Iterator<'_>, iterator_layout);
 
 impl fmt::Debug for Iterator<'_> {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
@@ -422,11 +414,7 @@ fn test_iterator() {
 #[repr(transparent)]
 pub struct Cliperator<'a>(SkRegion_Cliperator, PhantomData<&'a Region>);
 
-impl<'a> NativeTransmutable<SkRegion_Cliperator> for Cliperator<'a> {}
-#[test]
-fn test_cliperator_layout() {
-    Cliperator::test_layout();
-}
+native_transmutable!(SkRegion_Cliperator, Cliperator<'_>, cliperator_layout);
 
 impl Drop for Cliperator<'_> {
     fn drop(&mut self) {
@@ -479,11 +467,7 @@ impl<'a> iter::Iterator for Cliperator<'a> {
 #[repr(transparent)]
 pub struct Spanerator<'a>(SkRegion_Spanerator, PhantomData<&'a Region>);
 
-impl NativeTransmutable<SkRegion_Spanerator> for Spanerator<'_> {}
-#[test]
-fn test_spanerator_layout() {
-    Spanerator::test_layout();
-}
+native_transmutable!(SkRegion_Spanerator, Spanerator<'_>, spanerator_layout);
 
 impl Drop for Spanerator<'_> {
     fn drop(&mut self) {
