@@ -1,5 +1,8 @@
+#![macro_use]
 #![allow(clippy::upper_case_acronyms)]
 
+mod macros;
+
 pub mod codec;
 #[deprecated(since = "0.33.1", note = "use codec::Result")]
 pub use codec::Result as CodecResult;
@@ -38,9 +41,7 @@ pub use crate::pathops::*;
 
 #[cfg(test)]
 mod transmutation_tests {
-
-    use crate::prelude::NativeTransmutableSliceAccess;
-    use crate::Point;
+    use crate::{prelude::NativeTransmutableSliceAccess, Point};
     use skia_bindings::SkPoint;
 
     #[test]
